@@ -65,7 +65,7 @@ protected:
 	const kidxtype K;
 	const vertexidxtype N;
 	Progress& p;
-	int threshold = 0;
+	unsigned int threshold = 0;
 	int threshold2 = 0;
 
 	virtual double distanceFunction(const V& x_i, const V& x_j) const = 0;
